{% extends "bee_django_course/base.html" %}
{% load static %}
{% load bootstrap3 %}
{% block content %}

    <h4>{{ section_video.video.title }} 在课件 {{ section_video.section.name }} 里的排序</h4>

    <form method="post">
        {% csrf_token %}

        {% bootstrap_form form %}
        {% bootstrap_button '提交' %}
    </form>
{% endblock %}

