# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-03-17 09:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0006_auto_20180108_1846'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='course',
            name='type_int',
        ),
        migrations.AddField(
            model_name='section',
            name='has_imagework',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u9700\u8981\u4e0a\u4f20\u56fe\u7247'),
        ),
        migrations.AddField(
            model_name='section',
            name='has_textwork',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u9700\u8981\u6587\u5b57\u4f5c\u4e1a'),
        ),
        migrations.AddField(
            model_name='section',
            name='has_videowork',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u9700\u8981\u89c6\u9891\u5f55\u5236'),
        ),
        migrations.AddField(
            model_name='section',
            name='image_count_req',
            field=models.IntegerField(default=0, verbose_name='\u8981\u6c42\u63d0\u4ea4\u56fe\u7247\u6570\u91cf'),
        ),
        migrations.AddField(
            model_name='section',
            name='video_length_req',
            field=models.IntegerField(default=0, verbose_name='\u8981\u6c42\u5f55\u5236\u65f6\u957f(\u5206\u949f)'),
        ),
    ]
