# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-17 06:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0037_auto_20180615_1256'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usersectionnote',
            name='note',
            field=models.TextField(verbose_name='\u5b66\u4e60\u7b14\u8bb0'),
        ),
    ]
