# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-03-31 02:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0023_auto_20180330_1513'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userassignment',
            name='comment',
        ),
        migrations.RemoveField(
            model_name='userassignment',
            name='rejected_at',
        ),
        migrations.RemoveField(
            model_name='userassignment',
            name='reviewed_at',
        ),
        migrations.RemoveField(
            model_name='userassignment',
            name='status',
        ),
        migrations.RemoveField(
            model_name='userassignment',
            name='submit_at',
        ),
        migrations.RemoveField(
            model_name='userassignment',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='userassignment',
            name='work_time',
        ),
        migrations.RemoveField(
            model_name='usercoursesection',
            name='passed_at',
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='comment',
            field=models.TextField(blank=True, null=True, verbose_name='\u8bc4\u8bed'),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='updated_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='work_time',
            field=models.IntegerField(blank=True, default=0, null=True, verbose_name='\u603b\u5171\u7ec3\u4e60\u65f6\u95f4'),
        ),
    ]
