{% extends "bee_django_course/base.html" %}

{% block content %}
    <div class="text-center"><h3>
        我的录播作业
    </h3>
    </div>

    <div>共{{ paginator.count }}个</div>
    <table class="table">
        <thead>
        <tr>
            <th></th>
            <th></th>

        </tr>
        </thead>
        <tbody>
        {% for live in user_live_list %}
            <tr>
                <td>{{ forloop.counter }}</td>

                <td>
                    <a href="#">观看</a>
{#                    <a href="#" id="delete_{{ course.id }}"#}
{#                       data-confirm="{% url "bee_django_course:course_delete" course.id %}"#}
{#                       onclick="click_del(this)">删除</a>#}
                </td>
            </tr>

        {% endfor %}
        </tbody>
    </table>
    {% include 'bee_django_course/paginator.html' %}
{% endblock %}
{% block scripts %}
    <script>
{#        function click_del(_this) {#}
{#            if (!confirm('确认要执行这个操作？')) {#}
{#                return false;#}
{#            }#}
{#            var url = $(_this).attr('data-confirm');#}
{#            $.post(url).done(function (data) {#}
{#                alert('删除成功!');#}
{#                location.reload();#}
{#            });#}
{#        }#}
    </script>
{% endblock %}