{% extends "bee_django_course/base.html" %}
{% load bee_django_course_filter %}
{% block content %}

    <table class="table">
        {% for e in user_course %}
            <tr>
                <th>{{ e.course.name }}</th>
                <td>
                    <ul class="list-group">
                    {% for i in e.usercoursesection_set.all %}
                        <li class="list-group-item">
                            {{ i.section.name }}  <span class="bg-info">{{ i.status | course_status }}</span>
                        </li>
                    {% endfor %}
                    </ul>
                </td>
            </tr>
        {% endfor %}
    </table>


{% endblock content %}