# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-03-18 00:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0008_auto_20180317_0958'),
    ]

    operations = [
        migrations.AddField(
            model_name='section',
            name='textwork_info',
            field=models.TextField(blank=True, null=True, verbose_name='\u4f5c\u4e1a\u8bf4\u660e'),
        ),
        migrations.AlterField(
            model_name='section',
            name='info',
            field=models.TextField(blank=True, null=True, verbose_name='\u6b63\u6587'),
        ),
    ]
