# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-03-26 05:58
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0019_auto_20180326_1311'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userassignmentimage',
            name='user_assignment',
        ),
        migrations.AddField(
            model_name='userassignmentimage',
            name='user_course_section',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserCourseSection'),
        ),
    ]
