{% include 'bee_django_course/question/question-answer-template.html' %}
    <div id="questions">
        <question-answer v-for="question in questions" :key="question.id"
                         :question="question"></question-answer>
    </div>
    <div id="submit_answers">
        {% verbatim %}

        <div v-if="result==false">
            <button @click="check_answers()">提交</button>
        </div>
        <div v-else>恭喜你！全答对啦</div>
        <div v-if="url">
            <a :href="String(url)">返回</a>
        </div>
        <div v-if="error_message">{{ error_message }}</div>
        {% endverbatim %}
    </div>
