# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-04-17 06:59
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0026_auto_20180411_1343'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='usercoursesection',
            options={'ordering': ['-created_at']},
        ),
    ]
