# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-17 03:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0055_auto_20180914_1626'),
    ]

    operations = [
        migrations.AddField(
            model_name='coursesectionmid',
            name='pionts',
            field=models.IntegerField(default=0, verbose_name='\u901a\u8fc7\u540e\u83b7\u5f97\u7684M\u5e01'),
        ),
    ]
