# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-24 06:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0039_auto_20180622_1445'),
    ]

    operations = [
        migrations.AddField(
            model_name='usersectionnote',
            name='is_digest',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u7cbe\u534e'),
        ),
        migrations.AddField(
            model_name='usersectionnote',
            name='is_stick',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u7f6e\u9876'),
        ),
    ]
