# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-15 04:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0036_auto_20180615_1118'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usersectionnote',
            name='is_open',
            field=models.BooleanField(default=True, verbose_name='\u516c\u5f00\u7b14\u8bb0'),
        ),
    ]
