# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-17 07:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0056_coursesectionmid_pionts'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='section',
            name='pre_name',
        ),
        migrations.AddField(
            model_name='coursesectionmid',
            name='pre_name',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u524d\u7f00\u6807\u9898'),
        ),
    ]
