# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-08 08:38
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0003_section'),
    ]

    operations = [
        migrations.CreateModel(
            name='CourseSectionMid',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order_by', models.IntegerField(default=0, verbose_name='\u987a\u5e8f')),
                ('mins', models.IntegerField(blank=True, null=True, verbose_name='\u8fbe\u6807\u5206\u949f\u6570')),
                ('course', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.Course', verbose_name='\u8bfe\u7a0b')),
            ],
            options={
                'db_table': 'course_section_mid',
            },
        ),
        migrations.AlterField(
            model_name='section',
            name='info',
            field=models.CharField(max_length=180, null=True, verbose_name='\u8bf4\u660e'),
        ),
        migrations.AlterField(
            model_name='section',
            name='name',
            field=models.CharField(max_length=180, verbose_name='\u8bfe\u4ef6\u540d\u5b57'),
        ),
        migrations.AlterField(
            model_name='section',
            name='order_by',
            field=models.IntegerField(null=True, verbose_name='\u8bfe\u4ef6\u6392\u5e8f'),
        ),
        migrations.AddField(
            model_name='coursesectionmid',
            name='section',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.Section', verbose_name='\u8bfe\u4ef6'),
        ),
    ]
