{% extends "bee_django_course/base.html" %}
{% load static %}
{% load bootstrap3 %}
{% block content %}
    <h4>课程{{ mid.course.name }} -> 课件{{ mid.section.name }}</h4>
    <form method="post">
        {% csrf_token %}
        {% bootstrap_form form %}
        {% bootstrap_button '提交' %}
    </form>
{% endblock %}