{% extends "bee_django_course/base.html" %}
{% load bee_django_course_filter %}
{% block content %}
    <h4>录制视频详情</h4>
    <div class="video">
        <iframe src="{{ record_video_id | get_video_src }}" frameborder="0" width="100%" height="100%"></iframe>
    </div>

    {% include 'bee_django_course/_user_live_comments.html' with comment_form=comment_form comments=comments %}

{% endblock %}