# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-20 08:31
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0057_auto_20180917_1551'),
    ]

    operations = [
        migrations.RenameField(
            model_name='coursesectionmid',
            old_name='pionts',
            new_name='points',
        ),
    ]
