# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-12-21 06:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0002_auto_20171218_1738'),
    ]

    operations = [
        migrations.CreateModel(
            name='Section',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180)),
                ('order_by', models.IntegerField(null=True)),
                ('info', models.CharField(max_length=180, null=True)),
            ],
            options={
                'ordering': ['-id'],
                'db_table': 'bee_django_course_section',
            },
        ),
    ]
