{% extends "bee_django_course/user_base.html" %}
{% load bootstrap3 %}
{% block content %}

    <h3>课程列表</h3>
    {% for e in courses %}
        <div class="col-md-3">
            <div class="well">
                <a href="#">
                    <h4>{{ e.name }}</h4>
                </a>
            </div>
        </div>
    {% endfor %}

{% endblock content %}